@@ -6,6 +6,9 @@
 #'
 #' @param odk A dataframe, obtained from reading an ODK Briefcase
 #'   export of records collected with the WHO questionnaire.
+#' 
+#' @param id_col A character string of the column name (in odk) with the
+#' unique ID for each death.
 #'
 #' @examples
 #' \dontrun{
@@ -18,7 +21,7 @@
 #' 
 #' @export
 #'
-odk2openVA_2014 <- function(odk){
+odk2openVA_2014 <- function (odk, id_col = "meta.instanceID") {
 
     ## Input Data
     odkNames <- tolower(names(odk))
@@ -206,7 +209,7 @@ odk2openVA_2014 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData1y])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData1y])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData1y] <- NA
     odk[, indexData1y] <- as.numeric(odk[, indexData1y])
@@ -218,7 +221,7 @@ odk2openVA_2014 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData1m])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData1m])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData1m] <- NA
     odk[, indexData1m] <- as.numeric(odk[, indexData1m])
@@ -230,7 +233,7 @@ odk2openVA_2014 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData1d])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData1d])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData1d] <- NA
     odk[, indexData1d] <- as.numeric(odk[, indexData1d])
@@ -244,7 +247,7 @@ odk2openVA_2014 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData3])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData3])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData3] <- NA
     odk[, indexData3] <- as.numeric(odk[, indexData3])
@@ -257,7 +260,7 @@ odk2openVA_2014 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData4d])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData4d])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData4d] <- NA
     odk[, indexData4d] <- as.numeric(odk[, indexData4d])
@@ -269,7 +272,7 @@ odk2openVA_2014 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData4m])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData4m])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData4m] <- NA
     odk[, indexData4m] <- as.numeric(odk[, indexData4m])
@@ -281,7 +284,7 @@ odk2openVA_2014 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData4y])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData4y])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData4y] <- NA
     odk[, indexData4y] <- as.numeric(odk[, indexData4y])
@@ -293,7 +296,7 @@ odk2openVA_2014 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData5d])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData5d])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData5d] <- NA
     odk[, indexData5d] <- as.numeric(odk[, indexData5d])
@@ -305,7 +308,7 @@ odk2openVA_2014 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData5h])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData5h])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData5h] <- NA
     odk[, indexData5h] <- as.numeric(odk[, indexData5h])
@@ -317,7 +320,7 @@ odk2openVA_2014 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData5m])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData5m])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData5m] <- NA
     odk[, indexData5m] <- as.numeric(odk[, indexData5m])
@@ -1043,7 +1046,14 @@ odk2openVA_2014 <- function(odk){
     }
 
     # Add ID as first column
-    iv5Out <- cbind(as.character(odk$meta.instanceID), iv5Out)
+    indexID <- which(stri_endswith_fixed(odkNames, tolower(id_col)))
+    if (length(indexID)) {
+        iv5Out <- cbind(as.character(odk[, indexID]), iv5Out)
+    } else {
+        message("Did not find id_col, so assigning row numbers for IDs.",
+                call. = FALSE)
+        iv5Out <- cbind(as.character(1:nrow(iv5Out)), iv5Out)
+    }
 
     # Attach column names
     colnames(iv5Out) <- c("ID", iv5Names)
