@@ -7,6 +7,9 @@
 #' @param odk A dataframe, obtained from reading an ODK Briefcase
 #'   export of records collected with the WHO questionnaire.
 #'
+#' @param id_col A character string of the column name (in odk) with the
+#' unique ID for each death.
+#'
 #' @examples
 #' \dontrun{
 #' record_f_name <- system.file("sample", "who141_odk_export.csv", package = "CrossVA")
@@ -15,10 +18,10 @@
 #' }
 #'
 #' @importFrom stringi stri_endswith_fixed
-#' 
+#'
 #' @export
 #'
-odk2openVA_v141 <- function(odk){
+odk2openVA_v141 <- function (odk, id_col = "meta.instanceID") {
 
     ## Input Data
     odkNames <- tolower(names(odk))
@@ -197,7 +200,7 @@ odk2openVA_v141 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData1y])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData1y])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData1y] <- NA
     odk[, indexData1y] <- as.numeric(odk[, indexData1y])
@@ -209,7 +212,7 @@ odk2openVA_v141 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData1m])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData1m])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData1m] <- NA
     odk[, indexData1m] <- as.numeric(odk[, indexData1m])
@@ -221,7 +224,7 @@ odk2openVA_v141 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData1d])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData1d])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData1d] <- NA
     odk[, indexData1d] <- as.numeric(odk[, indexData1d])
@@ -235,7 +238,7 @@ odk2openVA_v141 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData3])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData3])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData3] <- NA
     odk[, indexData3] <- as.numeric(odk[, indexData3])
@@ -248,7 +251,7 @@ odk2openVA_v141 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData4d])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData4d])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData4d] <- NA
     odk[, indexData4d] <- as.numeric(odk[, indexData4d])
@@ -260,7 +263,7 @@ odk2openVA_v141 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData4m])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData4m])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData4m] <- NA
     odk[, indexData4m] <- as.numeric(odk[, indexData4m])
@@ -272,7 +275,7 @@ odk2openVA_v141 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData4y])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData4y])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData4y] <- NA
     odk[, indexData4y] <- as.numeric(odk[, indexData4y])
@@ -284,7 +287,7 @@ odk2openVA_v141 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData5d])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData5d])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData5d] <- NA
     odk[, indexData5d] <- as.numeric(odk[, indexData5d])
@@ -296,7 +299,7 @@ odk2openVA_v141 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData5h])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData5h])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData5h] <- NA
     odk[, indexData5h] <- as.numeric(odk[, indexData5h])
@@ -308,7 +311,7 @@ odk2openVA_v141 <- function(odk){
         sum(nonNumeric < 0, na.rm = TRUE) > 0,
         1, 0)
     numNA <- numNA + containsNA
-    if (containsNA > 0) indexNA <- c(indexNA, whoNames[indexData5m])
+    if (containsNA > 0) indexNA <- c(indexNA, odkNames[indexData5m])
     nonNumeric[nonNumeric < 0] <- NA
     odk[is.na(nonNumeric), indexData5m] <- NA
     odk[, indexData5m] <- as.numeric(odk[, indexData5m])
@@ -509,38 +512,51 @@ odk2openVA_v141 <- function(odk){
     #iv5Out[odk[ , indexDatam]<  1, 53] <- "y"
 
     #75) Did the fever last less than a week before death? fev <1w
-    indexData <- which(stri_endswith_fixed(odkNames, whoNames[75]))
-    iv5Out[odk[ , indexData]< 7, 75] <- "y"
-    iv5Out[odk[ , indexData]>=7, 75] <- "n"
+    indexData <- which(stri_endswith_fixed(odkNames, whoNames[74]))
+    indexData_days <- which(stri_endswith_fixed(odkNames, whoNames[75]))
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days]< 7, 75] <- "y"
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days]>=7, 75] <- "n"
+    iv5Out[odk[ , indexData]=="no", 75] <- "n"
 
     #76) Did the fever last at least one week, but less than 2 weeks before death? fev 1-2w
-    iv5Out[odk[ , indexData]>= 7 & odk[ , indexData]< 14, 76] <- "y"
-    iv5Out[odk[ , indexData]<  7,                         76] <- "n"
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days]<  7,                              76] <- "n"
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days]>= 7 & odk[ , indexData_days]< 14, 76] <- "y"
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days]>=14,                              76] <- "n"
+    iv5Out[odk[ , indexData]=="no", 76] <- "n"
 
     #77) Did the fever last at least 2 weeks before death? fev 2+w
-    iv5Out[odk[ , indexData]>= 14, 77] <- "y"
-    iv5Out[odk[ , indexData]<  14, 77] <- "n"
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days]>= 14, 77] <- "y"
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days]<  14, 77] <- "n"
+    iv5Out[odk[ , indexData]=="no", 77] <- "n"
+
+    #78) Did the fever continue until death
+    iv5Out[odk[ , indexData]=="no", 78] <- "n"
 
     #79) Was the fever severe? fev sev
-    indexData <- which(stri_endswith_fixed(odkNames, whoNames[79]))
-    iv5Out[tolower(odk[ , indexData])=="severe",   79] <- "y"
-    iv5Out[tolower(odk[ , indexData])=="mild",     79] <- "n"
-    iv5Out[tolower(odk[ , indexData])=="moderate", 79] <- "n"
+    indexData_sev <- which(stri_endswith_fixed(odkNames, whoNames[79]))
+    iv5Out[odk[ , indexData]=="yes" & tolower(odk[ , indexData_sev])=="severe",   79] <- "y"
+    iv5Out[odk[ , indexData]=="yes" & tolower(odk[ , indexData_sev])=="mild",     79] <- "n"
+    iv5Out[odk[ , indexData]=="yes" & tolower(odk[ , indexData_sev])=="moderate", 79] <- "n"
+    iv5Out[odk[ , indexData]=="no", 79] <- "n"
 
     #80) Was the fever continuous? fev cont
-    indexData <- which(stri_endswith_fixed(odkNames, whoNames[80]))
-    iv5Out[tolower(odk[ , indexData])=="continuous", 80] <- "y"
-    iv5Out[tolower(odk[ , indexData])=="nightly",    80] <- "n"
-    iv5Out[tolower(odk[ , indexData])=="on_and_off", 80] <- "n"
+    indexData_cont <- which(stri_endswith_fixed(odkNames, whoNames[80]))
+    iv5Out[odk[ , indexData]=="yes" & tolower(odk[ , indexData_cont])=="continuous", 80] <- "y"
+    iv5Out[odk[ , indexData]=="yes" & tolower(odk[ , indexData_cont])=="nightly",    80] <- "n"
+    iv5Out[odk[ , indexData]=="yes" & tolower(odk[ , indexData_cont])=="on_and_off", 80] <- "n"
+    iv5Out[odk[ , indexData]=="no", 80] <- "n"
 
     #83) Did the cough last less than 3 weeks before death? cou <3w
-    indexData <- which(stri_endswith_fixed(odkNames, whoNames[83]))
-    iv5Out[odk[ , indexData[1]]< 21, 83] <- "y"
-    iv5Out[odk[ , indexData[1]]>=21, 83] <- "n"
+    indexData <- which(stri_endswith_fixed(odkNames, whoNames[82]))
+    indexData_days <- which(stri_endswith_fixed(odkNames, whoNames[83]))
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days[1]]< 21, 83] <- "y"
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days[1]]>=21, 83] <- "n"
+    iv5Out[odk[ , indexData]=="no", 83] <- "n"
 
     #84) Did the cough last at least 3 weeks before death? cou 3+w
-    iv5Out[odk[ , indexData[1]]>=21, 84] <- "y"
-    iv5Out[odk[ , indexData[1]]< 21, 84] <- "n"
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days[1]]>=21, 84] <- "y"
+    iv5Out[odk[ , indexData]=="yes" & odk[ , indexData_days[1]]< 21, 84] <- "n"
+    iv5Out[odk[ , indexData]=="no", 84] <- "n"
 
     #90) Did the difficult breathing last for at least 3 days before death? dif br 3d
     indexDatad <- which(stri_endswith_fixed(odkNames, whoNames[90]))
@@ -630,7 +646,8 @@ odk2openVA_v141 <- function(odk){
     iv5Out[odk[ , indexData]<  3, 117] <- "n"
 
     #123) Did (s)he have severe abdominal pain for less than 2 weeks before death? abd p <2w
-    indexData  <- which(stri_endswith_fixed(odkNames, whoNames[122]))
+    ## indexData  <- which(stri_endswith_fixed(odkNames, whoNames[122]))
+    indexData <- which(stri_endswith_fixed(odkNames, "id10195"))
     indexDatad <- which(stri_endswith_fixed(odkNames, "id10197"))
     indexDatah <- which(stri_endswith_fixed(odkNames, "id10196"))
     indexDataw <- which(stri_endswith_fixed(odkNames, "id10197b"))
@@ -720,6 +737,7 @@ odk2openVA_v141 <- function(odk){
     iv5Out[tolower(odk[ , indexData])=="no",                                                       133] <- "n"
 
     #136) Did (s)he have a stiff neck for less than one week before death? st n <1w
+    indexData  <- which(stri_endswith_fixed(odkNames, "id10208"))
     indexDatad <- which(stri_endswith_fixed(odkNames, whoNames[136]))
     iv5Out[tolower(odk[ , indexData])=="yes" & odk[ , indexDatad]< 7, 136] <- "y"
     iv5Out[tolower(odk[ , indexData])=="yes" & odk[ , indexDatad]>=7, 136] <- "n"
@@ -737,14 +755,21 @@ odk2openVA_v141 <- function(odk){
     iv5Out[tolower(odk[ , indexData])=="no",                          139] <- "n"
 
     #141) Did (s)he have mental confusion for at least 3 months before death? menc 3+m
+    indexData <- which(stri_endswith_fixed(odkNames, whoNames[140]))
     indexDatad <- which(stri_endswith_fixed(odkNames, whoNames[141]))
-    iv5Out[odk[ , indexDatad]>=3, 141] <- "y"
-    iv5Out[odk[ , indexDatad]< 3, 141] <- "n"
+    iv5Out[tolower(odk[ , indexData])=="yes" & odk[ , indexDatad]>=3, 141] <- "y"
+    iv5Out[tolower(odk[ , indexData])=="yes" & odk[ , indexDatad]< 3, 141] <- "n"
+    iv5Out[tolower(odk[ , indexData])=="no", 141] <- "n"
+
+    #143) Was (s)he unsconscious for at least 24 hours before death?	unc 24+h
+    indexData <- which(stri_endswith_fixed(odkNames, whoNames[142]))
+    iv5Out[odk[ , indexData]=="no", 143] <- "n"
 
     #144) Was (s)he unsconscious for at least 6 hours before death?	unc 6+h
-    indexData <- which(stri_endswith_fixed(odkNames, whoNames[144]))
-    iv5Out[odk[ , indexData]>=6, 144] <- "y"
-    iv5Out[odk[ , indexData]< 6, 144] <- "n"
+    indexData <- which(stri_endswith_fixed(odkNames, whoNames[143]))
+    indexDatah <- which(stri_endswith_fixed(odkNames, whoNames[144]))
+    iv5Out[odk[ , indexDatah]>=6, 144] <- "y"
+    iv5Out[odk[ , indexDatah]< 6, 144] <- "n"
 
     #149) Did the convulsions last for less than 10 minutes?	conv <10m
     indexData <- which(stri_endswith_fixed(odkNames, whoNames[149]))
@@ -963,6 +988,7 @@ odk2openVA_v141 <- function(odk){
     indexData <- which(stri_endswith_fixed(odkNames, whoNames[293]))
     iv5Out[odk[ , indexData]>=9 & odk[ , indexData]< 88, 293] <- "y"
     iv5Out[odk[ , indexData]< 9,                         293] <- "n"
+    iv5Out[odk[ , indexData]==88, 293] <- "."
 
     #294) Was the baby born during the eighth month (34 to 37 weeks) of pregnancy?	gest 8m
     iv5Out[odk[ , indexData]> 8 & odk[ , indexData]< 88, 294] <- "n"
@@ -1035,7 +1061,14 @@ odk2openVA_v141 <- function(odk){
     }
 
     # Add ID as first column
-    iv5Out <- cbind(as.character(odk$meta.instanceID), iv5Out)
+    indexID <- which(stri_endswith_fixed(odkNames, tolower(id_col)))
+    if (length(indexID)) {
+        iv5Out <- cbind(as.character(odk[, indexID]), iv5Out)
+    } else {
+        message("Did not find id_col, so assigning row numbers for IDs.",
+                call. = FALSE)
+        iv5Out <- cbind(as.character(1:nrow(iv5Out)), iv5Out)
+    }
 
     # Attach column names
     colnames(iv5Out) <- c("ID", iv5Names)
